#include <clientserv.h>

/////////////////////////////////////////////////////////////////////////////////////////
static int _send(int sock, const unsigned char *buf, int size)
{
	const unsigned char* ptr;
	int wrt, nwrt;

	nwrt = size;
	ptr = buf;
	while (nwrt > 0)
	{
		if ((wrt = send(sock, ptr, nwrt, MSG_NOSIGNAL)) <= 0)
		{
			
			if (((errno == EAGAIN) || (errno == EINTR)) && (wrt < 0))
				wrt = 0;
			else
			{	
			  printf("wrt=%d\n", wrt); 
			
			  return (size - nwrt);
			}
			  
		}
		nwrt -= wrt;
		ptr += wrt;
	}

	return (size);
} /* _send */

/////////////////////////////////////////////////////////////////////////////////////////
//Функция возвращает длину успешно переданных данных (но меньшую, чем влезает в int)
int ucnet_send(int sock, const unsigned char *buf, int size)
{
	unsigned char *msg;
	int err;

	if (!(msg = calloc(1, size + sizeof(int))))
		return (-1);
	*(int*) msg = htonl(size);
	memcpy(msg + sizeof(int), buf, size);

	err = _send(sock, msg, size + sizeof(int));
	free(msg);

	if (err > sizeof(int))
		err -= sizeof(int);

	return (err);
} /* ucnet_send */


int main()
{
	struct sockaddr_in addr;
	char message[MESS_LEN];
	int sock, ip, send_bytes, len=MESS_LEN;

	/*Создаем сокет*/
	//AF_INET - семейство адресов Internet-домена
	//SOCK_STREAM - Передача потока данных с предварительной установкой соединения
	//IPPROTO_TCP - протокол TCP
	sock = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
	if(sock < 0)
	{	/*Если сокет не создался*/
		printf("ERROR: socket failure.\n");
		return (-1);
	}
	else /*Сообщаем об успехе*/
		printf("socket complete.\n");
	
	/*Преобразование IP-адреса из строкового типав сетевой*/
	//AF_INET - Internet-домен
	//IP_ADDRESS - текстовый формат ip-адреса (см. define)
	//ip - возвращаемый указатель (void) на IP в сетевом виде
	
	if ((inet_pton(AF_INET, IP_ADDRESS, &ip)) <= 0) 
	{	
		printf("ERROR: inet_pton failure. res=\n");
		return(-1);
	}
	/*Заполняем структуру адреса данными сервера*/
	addr.sin_family = AF_INET;	//Internet-домен
	addr.sin_port = htons(PORT);//Номер порта сервера (см. define) 
	addr.sin_addr.s_addr = ip;	//ip-адрес сервера
	
	/*Устанавливаем соединение*/
	//sock - сокет, который будет использоваться для обмена данными с сервером
	//(struct sockaddr *)&addr - указатель на структуру с адресом сервера
	//sizeof(addr) - длина структуры с адресом сервера
	if(connect(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0)
	{
		printf("ERROR: connect failure.\n");
		return (-1);
	}
	else /*Сообщаем об успехе*/
		printf("connect complete.\n");

	/*Генерируем рандом*/
	
	unsigned char *random_msg = calloc(len,1);
		int i, rnd;

		for(i=0; i<(len)/4; i++)
		{
			rnd = rand();
			memcpy(random_msg+i*4,&rnd,4);
		}
	
	if ((send_bytes = ucnet_send(sock, random_msg, len)) > 0)
	{	
	    printf("SEND OK\nsend_bytes = %d\n", send_bytes);
	
	    /*Печать сообщения на экран*/
	    /*printf("msg: ");
			for (i=0; i<len;i++)
				printf("%02x |",random_msg[i]);
			printf("\n");*/
	}
	else
	{
	    printf("SEND ERROR\nsend_bytes = %i\n", send_bytes);
	    return (-1);
	}



	/*Закрытие соединения*/
	close(sock);
	free(random_msg);

	return 0;
}
